<?php
/**
 * paper functions and definitions
 *
 * @package paper
 * @since paper 1.0
 */
/*
==========================================================
AUTOMATIC UPDATES
==========================================================
*/

/**
 * Set the content width based on the theme's design and stylesheet.
 *
 * @since paper 1.0
 */
if ( ! isset( $content_width ) )
	$content_width = 680; /* pixels */

if ( ! function_exists( 'paper_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which runs
 * before the init hook. The init hook is too late for some features, such as indicating
 * support post thumbnails.
 *
 * @since paper 1.0
 */
function paper_setup() {
	/**
	 * Make theme available for translation
	 * Translations can be filed in the /languages/ directory
	 * If you're building a theme based on paper, use a find and replace
	 * to change 'paper' to the name of your theme in all the template files
	 */
	load_theme_textdomain( 'paper', get_template_directory() . '/languages' );

	/* Add default posts and comments RSS feed links to head */
	add_theme_support( 'automatic-feed-links' );

	/* Enable support for Post Thumbnails */
	add_theme_support( 'post-thumbnails' );

	/* This theme uses wp_nav_menu() in one location. */
	register_nav_menus( array(
		'primary' => __( 'Primary Menu', 'paper' ),
	) );

	/* Add support for the Aside Post Formats */
	add_theme_support( 'post-formats', array( 'aside', ) );
}
endif; // paper_setup
add_action( 'after_setup_theme', 'paper_setup' );

/* Custom template tags for this theme. */
require( get_template_directory() . '/inc/template-tags.php' );

/* Custom functions that act independently of the theme templates */
require( get_template_directory() . '/inc/extras.php' );

/* Load custom paper Theme Customizer options. */
require( get_template_directory() . '/inc/template-customizer.php' );

/**
 * Register widgetized area and update sidebar with default widgets
 *
 * @since paper 1.0
 */
function paper_widgets_init() {
	register_sidebar( array(
		'name' => __( 'Sidebar', 'paper' ),
		'id' => 'sidebar-1',
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget' => '</aside>',
		'before_title' => '<h3 class="widget-title">',
		'after_title' => '</h3>',
	) );
}
add_action( 'widgets_init', 'paper_widgets_init' );

/**
 * Enqueue scripts and styles
 */
function paper_scripts() {
if ( ! is_admin() ) {
		wp_enqueue_style( 'style', get_stylesheet_uri() );
     }

	wp_enqueue_script( 'small-menu', get_template_directory_uri() . '/js/small-menu.js', array( 'jquery' ), '20120206', true );

	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
		wp_enqueue_script( 'comment-reply' );
	}

	if ( is_singular() && wp_attachment_is_image() ) {
		wp_enqueue_script( 'keyboard-image-navigation', get_template_directory_uri() . '/js/keyboard-image-navigation.js', array( 'jquery' ), '20120202' );
	}
}
add_action( 'wp_enqueue_scripts', 'paper_scripts' );

/**
 * Implement the Custom Header feature
 */